/*
  Copyright 2003 John Knottenbelt
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
*/

#include "config.h"
#include "tuneparams.h"
#include "dvbd.h"
#include "stringutil.h"

#include <cstdlib>
#include <string>
#include <iostream>
#include <fstream>
#include <cassert>

/* Read in the channels.conf file */
bool readChannelsConf(const std::string &type, const std::string &filename, std::map<std::string, TuneParams *> &channels)
{
  std::ifstream input(filename.c_str());
  if (!input) {
    std::cerr << "Failed to open " << filename << " for reading\n";
    return false;
  }

  std::string line;
  while (getline(input, line, '\n')) {
    line = stripTrailingWS(stripLeadingWS(stripLineComment(line)));
    
    // Skip blank lines
    if (line == "")
      continue;
    
    TuneParams *p = NULL;

    if (type == "dvb-t") 
      p = DVBTTuneParams::createFromTZAP(line);
    else if (type == "dvb-s")
      p = DVBSTuneParams::createFromSZAP(line);
    else if (type == "dvb-c")
      p = DVBCTuneParams::createFromCZAP(line);
    else {
      std::cerr << "Type " << type << " not implemented (yet)" << std::endl;
      input.close();
      return false;
    }

    assert(p != NULL);
    channels[p->getName()] = p;
  }

  input.close();
  return true;
}
